summaryrefslogtreecommitdiffstats
path: root/src/usr/fapi2/test/fapi2GetChildrenTest.H
diff options
context:
space:
mode:
authorPrachi Gupta <pragupta@us.ibm.com>2017-03-24 14:17:48 -0500
committerDaniel M. Crowell <dcrowell@us.ibm.com>2017-05-23 14:02:55 -0400
commit3d40df249d4ff2f2f6a3c17dcab7d069a355d28a (patch)
treec4dae42b02565637586d2c254ab8077a3dac1658 /src/usr/fapi2/test/fapi2GetChildrenTest.H
parentda1946689af4b765c9ad5c6a7f64cc4f34df252a (diff)
downloadtalos-hostboot-3d40df249d4ff2f2f6a3c17dcab7d069a355d28a.tar.gz
talos-hostboot-3d40df249d4ff2f2f6a3c17dcab7d069a355d28a.zip
Changing NV target to OBUS_BRICK and mark it a child of OBUS
Change-Id: I17b52033d1e6811c320f201056708f31ef34d0e9 RTC:171597 Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/38481 Tested-by: Jenkins Server <pfd-jenkins+hostboot@us.ibm.com> Tested-by: Jenkins OP Build CI <op-jenkins+hostboot@us.ibm.com> Tested-by: FSP CI Jenkins <fsp-CI-jenkins+hostboot@us.ibm.com> Reviewed-by: William G. Hoffa <wghoffa@us.ibm.com> Reviewed-by: Matthew A. Ploetz <maploetz@us.ibm.com> Reviewed-by: Daniel M. Crowell <dcrowell@us.ibm.com>
Diffstat (limited to 'src/usr/fapi2/test/fapi2GetChildrenTest.H')
-rw-r--r--src/usr/fapi2/test/fapi2GetChildrenTest.H8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/usr/fapi2/test/fapi2GetChildrenTest.H b/src/usr/fapi2/test/fapi2GetChildrenTest.H
index 8fd90c851..946983338 100644
--- a/src/usr/fapi2/test/fapi2GetChildrenTest.H
+++ b/src/usr/fapi2/test/fapi2GetChildrenTest.H
@@ -304,12 +304,12 @@ void test_fapi2GetChildren()
{ return i_perv.getChildren<fapi2::TARGET_TYPE_CAPP>(
TARGET_STATE_PRESENT).size(); } },
- // NV pervasive has 1 NV children
- {PERV_NV_CHILDREN,
+ // OBUS pervasive has 3 OBUS BRICK children
+ {PERV_OBUS_BRICK_CHILDREN,
[](TARGETING::ATTR_CHIP_UNIT_type i_unit)
- { return (i_unit == NV_RANGE); },
+ { return ((i_unit >= OBUS_LOW) && (i_unit <= OBUS_HIGH)); },
[](Target<fapi2::TARGET_TYPE_PERV>& i_perv)
- { return i_perv.getChildren<fapi2::TARGET_TYPE_NV>(
+ { return i_perv.getChildren<fapi2::TARGET_TYPE_OBUS_BRICK>(
TARGET_STATE_PRESENT).size(); } },
// MCBIST/MCS/MCA pervasive has 1 MCBIST child
OpenPOWER on IntegriCloud